@@ -434,6 +434,14 @@ mod tests {
         }
     }
 
+    #[test]
+    fn asym() {
+        log_init();
+
+        let g = UnGraph::<(), ()>::from_edges([(0, 1), (1, 0)]);
+        assert!(is_isomorphic(&g, &g.clone().into_canon()));
+    }
+
     #[test]
     fn empty() {
         log_init();
